@@ -77,12 +77,6 @@ impl ZeroCopy {
                     ) {
                         Ok(len) => {
                             total_transferred += len as usize;
-                            current_offset += len as off_t;
-                            trace!(
-                                "actual: zero copy bytes transferred: {} out of {}",
-                                len,
-                                size
-                            );
 
                             if total_transferred < size as usize {
                                 debug!(
@@ -90,13 +84,27 @@ impl ZeroCopy {
                                     total_transferred, size
                                 );
                             } else {
+                                trace!(
+                                    "actual: zero copy bytes transferred: {} out of {}, ",
+                                    len,
+                                    size
+                                );
+
                                 return Ok(len as usize);
                             }
                         }
-                        Err(err) => {
-                            log::error!("error sendfile: {}", err);
-                            return Err(err.into());
-                        }
+                        Err(err) => match err {
+                            nix::errno::Errno::EAGAIN => {
+                                debug!(
+                                    "EAGAIN, continuing source: {},target: {}",
+                                    source_fd, target_fd
+                                );
+                            }
+                            _ => {
+                                log::error!("error sendfile: {}", err);
+                                return Err(err.into());
+                            }
+                        },
                     }
                 }
             })
@@ -146,11 +154,9 @@ impl ZeroCopy {
                             }
                         }
                         Err(err) => {
-                            if let NixError::Sys(err_no) = err {
-                                if err_no == Errno::EAGAIN {
-                                    debug!("EAGAIN, try again");
-                                    continue;
-                                }
+                            if err == Errno::EAGAIN {
+                                debug!("EAGAIN, try again");
+                                continue;
                             }
 
                             log::error!("error sendfile: {}", err);
